<?php

# Function to convert HSV values to RGB

function hsv2rgb($hue, $saturation, $value, &$red, &$green, &$blue) {

   if ($saturation == 0) {
      $red = $value;
      $green = $value;
      $blue = $value;
   } else {
      if ($hue == 6) $hue = 0;
      $i = floor($hue);  # the integer part of hue
      $f = $hue - $i;
      $p = $value * (1 - $saturation);
      $q = $value * (1 - ($saturation * $f));
      $t = $value * (1 - ($saturation * (1 - $f)));
      switch ($i) {
         case 0:
            $red = $value;
            $green = $t;
            $blue = $p;
            break;
         case 1:
            $red = $q;
            $green = $value;
            $blue = $p;
            break;
         case 2:
            $red = $p;
            $green = $value;
            $blue = $t;
            break;
         case 3:
            $red = $p;
            $green = $q;
            $blue = $value;
            break;
         case 4:
            $red = $t;
            $green = $p;
            $blue = $value;
            break;
         case 5:
            $red = $value;
            $green = $p;
            $blue = $q;
            break;
      } # end switch
   } # end if else

} # end function

# These values need to be the same as those that produced the spectrum image:

$box_x = 256;
$box_y = 25;

$min_value = 0.3;
$max_value = 1.0;
$value_inc = ($max_value - $min_value) / $box_y;

$min_hue = 0;
$max_hue = 6;
$hue_inc = ($max_hue - $min_hue) / $box_x;

$max_saturation = 0.9;
$min_saturation = 0.0;
$saturation_inc = ($max_saturation - $min_saturation) / $box_y;

# Use the coordinates only if they are non-zero:

if (($x > 0) && ($y > 0)) {
   $ox = $x;
   $oy = $y;
} else {
   $x = $ox;
   $y = $oy;
} # end if else

# Calculate HSV based on given coordinates and convert to RGB:

$hue = $hue_inc * $x;
if ($y <= $box_y) {
   $saturation = $max_saturation;
   $value = $min_value + ($value_inc * $y);
} else {
   $value = $max_value - $value_inc;
   $saturation = $max_saturation - ($saturation_inc * ($y - $box_y));
} # end if else

hsv2rgb($hue, $saturation, $value, $red, $green, $blue);

# The RGB values are returned in the interval [0..1] so we
# need to multiply by 256 to get "normal" color values.
# We also need to convert the color values to a hex string:

$red = min(255, floor($red * 256));
$green = min(255, floor($green * 256));
$blue = min(255, floor($blue * 256));

echo "<!-- $patch_color -->\n";
if (!isset($HTTP_GET_VARS[patch_color])) {
	$patch_color = substr("0" . dechex($red), -2) . substr("0" . dechex($green), -2) . substr("0" . dechex($blue), -2);
}

echo "<!-- ($x, $y) = HSV($hue, $saturation, $value) -->\n";
echo "<!-- $patch_color = $red + $green + $blue -->\n";

echo "<html>\n";
echo "<head>\n";

echo "<script language='javascript'>\n";

echo "   var tempX = 0\n";
echo "   var tempY = 0\n";
echo "   var IE = document.all?true:false\n";
echo "   if (!IE) document.captureEvents(Event.MOUSEMOVE)\n";
echo "   document.onmousemove = getMouseXY;\n";

echo "   function getMouseXY(e) {\n";
echo "      if (IE) {\n";
echo "         tempX = event.clientX + document.body.scrollLeft\n";
echo "         tempY = event.clientY + document.body.scrollTop\n";
echo "      } else {\n";
echo "         tempX = e.pageX\n";
echo "         tempY = e.pageY\n";
echo "      }\n";
echo "      if (tempX < 0){tempX = 0}\n";
echo "      if (tempY < 0){tempY = 0}\n";
echo "      return true\n";
echo "   }\n";

echo "   function SetColor() {\n";
echo "      location.href = \"spectrum.php?x=\" + tempX + \"&y=\" + tempY + \"&ox=" . $ox . "&oy=" . $oy . "\";\n";
echo "   }\n";

echo "</script>\n";

echo "</head>\n";

echo "<body bgcolor='#000000'>\n";
echo "<table border='0' cellspacing='0' cellpadding='0' width='100%' height='100%'>\n";
echo "<tr><td align='center' valign='middle'>\n";
echo "<table border='0' cellspacing='0' cellpadding='0'><tr><td><img src='/images/spectrum2.png' border='0' onClick='SetColor()'></td><td width='50' bgcolor='#" . $patch_color . "' align='center'><a href='chat_input.php?PHPSESSID=" . $PHPSESSID . "&patch_color=" . $patch_color . "&nc=" . $patch_color . "&ox=" . $ox . "&oy=" . $oy . "' target='_parent'><img src='/images/trans50x50.gif' border='0'></a></td></tr></table>\n";
echo "</td></tr></table>\n";
echo "</body></html>\n";

?>